/*
		 symax0.3.h

    By P.Costigan email: pcscada@vicnet.net.au
    This program contains the protocol for reading and writing
    to a SY/MAX processor (industrial controller) via a serial port.

    Copyright (C) 1998 Philip Costigan   P.C. SCADA LINK PTY. LTD.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


*/

#ifndef SYMAX_H
#define SYMAX_H

#define DIAG 


#ifdef DIAG

/* This function is used only when diagnostics are required.
   The data sent and received from the SY/MAX device is sent to standard error
   in a format like [10][15] which is a DLE followed by a NAK.
*/
	void PrintRecInfo( int );	/* display Data */
	void PrintSendInfo( int );
#endif






/* set up an I/O map to receive data in to from SY/MAX processors */
#define IO_MAP_SIZE 4000
short int io_map[ IO_MAP_SIZE ];

/* Open the serial comm port for communications to a processor or network
   interface module */

int open_symax_port( char *device );



/* make port communicate with SY/MAX devices..
   this function must be continually called to update the I/O map above */

void symax_comms( int file );



/* To read data directly from a processor to a local array use this 
   function.  The return value of FALSE indicates that the function
   is busy and that the calling function will not receive any data.
   If TRUE is returned then the request is being processed.
   When the value of status is equal to DATA_COMMS_OK then data is
   available at *local. */

int tread( int *status, int *route, int *local, int remote, int count );



/* To write directly to a processor from a local array use this
   function. The return value of FALSE indicates that the function
   is busy and that the calling function will not send any data.
   If TRUE is returned then the request is being processed.
   When the value of status is equal to DATA_COMMS_OK then data has
   been sent sucsessfully. */

int twrite( int *status, int *route, int *local, int remote, int count );




#endif



